==> kdebase-4.1.4-i586-P1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libdolphinprivate.so.4 )
( cd opt/kde/lib ; ln -sf libdolphinprivate.so.4.1.0 libdolphinprivate.so.4 )
( cd opt/kde/lib ; rm -rf libkonq.so )
( cd opt/kde/lib ; ln -sf libkonq.so.5 libkonq.so )
( cd opt/kde/lib ; rm -rf libkonqsidebarplugin.so )
( cd opt/kde/lib ; ln -sf libkonqsidebarplugin.so.4 libkonqsidebarplugin.so )
( cd opt/kde/lib ; rm -rf libkonquerorprivate.so )
( cd opt/kde/lib ; ln -sf libkonquerorprivate.so.4 libkonquerorprivate.so )
( cd opt/kde/lib ; rm -rf libkonquerorprivate.so.4 )
( cd opt/kde/lib ; ln -sf libkonquerorprivate.so.4.1.0 libkonquerorprivate.so.4 )
( cd opt/kde/lib ; rm -rf libkonqsidebarplugin.so.4 )
( cd opt/kde/lib ; ln -sf libkonqsidebarplugin.so.4.1.0 libkonqsidebarplugin.so.4 )
( cd opt/kde/lib ; rm -rf libdolphinprivate.so )
( cd opt/kde/lib ; ln -sf libdolphinprivate.so.4 libdolphinprivate.so )
( cd opt/kde/lib ; rm -rf libkonq.so.5 )
( cd opt/kde/lib ; ln -sf libkonq.so.5.1.0 libkonq.so.5 )
( cd opt/kde/share/doc/HTML/en/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konqueror ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/dolphin ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/dolphin ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kwrite ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfind ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konsole ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kdepasswd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdepasswd ; ln -sf /opt/kde/share/doc/HTML/en/common common )

==> kdebase-4.2.4-i586-P1.tgz: install/doinst.sh <==
( cd opt/kde/lib ; rm -rf libkonqsidebarplugin.so.4 )
( cd opt/kde/lib ; ln -sf libkonqsidebarplugin.so.4.2.0 libkonqsidebarplugin.so.4 )
( cd opt/kde/lib ; rm -rf libkonqsidebarplugin.so )
( cd opt/kde/lib ; ln -sf libkonqsidebarplugin.so.4 libkonqsidebarplugin.so )
( cd opt/kde/lib ; rm -rf libkonq.so.5 )
( cd opt/kde/lib ; ln -sf libkonq.so.5.2.0 libkonq.so.5 )
( cd opt/kde/lib ; rm -rf libkonquerorprivate.so )
( cd opt/kde/lib ; ln -sf libkonquerorprivate.so.4 libkonquerorprivate.so )
( cd opt/kde/lib ; rm -rf libkonquerorprivate.so.4 )
( cd opt/kde/lib ; ln -sf libkonquerorprivate.so.4.2.0 libkonquerorprivate.so.4 )
( cd opt/kde/lib ; rm -rf libdolphinprivate.so )
( cd opt/kde/lib ; ln -sf libdolphinprivate.so.4 libdolphinprivate.so )
( cd opt/kde/lib ; rm -rf libdolphinprivate.so.4 )
( cd opt/kde/lib ; ln -sf libdolphinprivate.so.4.2.0 libdolphinprivate.so.4 )
( cd opt/kde/lib ; rm -rf libkonq.so )
( cd opt/kde/lib ; ln -sf libkonq.so.5 libkonq.so )
( cd opt/kde/share/doc/HTML/en/kdepasswd ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kdepasswd ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kfind ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/dolphin ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/dolphin ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konsole ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kwrite ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konqueror ; ln -sf /opt/kde/share/doc/HTML/en/common common )
